'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var pkg = require('../../package.json');

module.exports = yeoman.Base.extend({
  prompting: function () {
    // Have Yeoman greet the user.
    this.log(yosay(
      'Bienvenido al ' + chalk.red('generator-ec') + ' generador de proyectos front-end! Version ' + pkg.version
    ));

    var prompts = [{
      type: 'input',
      name: 'name',
      message: 'Nombre del Proyecto',
      default: this.appname.replace(/ /g, "-")  // Default to current folder name
    }, {
      type: 'input',
      name: 'autor',
      message: 'Nombre del autor',
      default: "GEC"
    },{
      type: 'input',
      name: 'port',
      message: 'Puerto del Servidor',
      default: "8080"
    }, {
      type: 'confirm',
      name: 'cool',
      message: 'Estas seguro de continuar?'
    }];

    return this.prompt(prompts).then(function (props) {
      // To access props later use this.props.someAnswer;
      this.props = props;
      this.props.name = props.name.replace(/ /g, "-")
    }.bind(this));
  },

  writing: function () {

    this.destinationRoot( this.props.name );

    this.fs.copy(
      this.templatePath('_gulp.js'),
      this.destinationPath('gulpfile.js')
    );

    this.fs.copy(
      this.templatePath('_.editorconfig'),
      this.destinationPath('.editorconfig')
    );

    this.fs.copy(
      this.templatePath('_.gitignore'),
      this.destinationPath('.gitignore')
    );

    this.fs.copyTpl(
      this.templatePath('_package.json'),
      this.destinationPath('package.json'), {
        name: this.props.name,
        autor: this.props.autor
      }
    );

    this.fs.copyTpl(
      this.templatePath('_.my'),
      this.destinationPath('.my.json'), {
        port: this.props.port
      }
    );

    /* folder source */
    this.fs.copy(
      this.templatePath('source/jade/_index.jade'),
      this.destinationPath('source/jade/index.jade')
    );

    this.fs.copy(
      this.templatePath('source/jade/_partials/_head.jade'),
      this.destinationPath('source/jade/_partials/head.jade')
    );

    this.fs.copy(
      this.templatePath('source/jade/_layouts/_example.jade'),
      this.destinationPath('source/jade/_layouts/example.jade')
    );

    this.fs.copy(
      this.templatePath('source/jade/_modules/_example.jade'),
      this.destinationPath('source/jade/_modules/example.jade')
    );

    this.fs.copy(
      this.templatePath('source/js/_main.js'),
      this.destinationPath('source/js/main.js')
    );

    this.fs.copy(
      this.templatePath('source/sass/_main.sass'),
      this.destinationPath('source/sass/main.sass')
    );

    /* folder public */
    this.fs.copy(
      this.templatePath('public/img/_tmp.jpg'),
      this.destinationPath('public/img/tmp.jpg')
    );

  },

  install: function () {
    this.installDependencies({bower: false});
  }
});
