var notify = require('gulp-notify');
var jadeInheritance = require('gulp-jade-inheritance');
var changed = require('gulp-changed');
var cached = require('gulp-cached');
var gulpif = require('gulp-if');
var filter = require('gulp-filter');

var watchify = require('watchify');
var assign = require('lodash.assign');
var argv = require('yargs').argv;
var glob = require('glob');

var gulp = require('gulp'),
  jade = require('gulp-jade'),
  connect = require('gulp-connect'),
  open = require('gulp-open'),
  compression = require('compression'),
  uglify = require('gulp-uglifyjs'),
  es = require('event-stream'),
  rename = require('gulp-rename'),
  fs = require('fs'),

  source = require('vinyl-source-stream'),
  buffer = require('vinyl-buffer'),
  sass = require('gulp-sass'),
  sourcemaps = require('gulp-sourcemaps'),
  autoprefixer = require('gulp-autoprefixer'),
  gutil = require('gulp-util'),
  browserify = require('browserify'),
  modernizr = require('modernizr'),
  download = require("gulp-download-stream"),
  concat = require('gulp-concat'),

// For use create file my.json
  my = function() {
    var filePath = __dirname + '/.my.json';
    try {
      fs.statSync(filePath);
    } catch (err) {
      if (err.code == 'ENOENT') return {};
    }
    return require(filePath);
  }();

require('es6-promise').polyfill(); // for autoprefixer

var path = {
  jade: {
    watch: ['source/jade/**/*.jade'],
    from: 'source/jade/*.jade'
  },
  sass: {
    watch: ['source/sass/**/*.sass'],
    from: 'source/sass/main.sass'
  }
};

var config = {
  port: my.MY_SERVER_PORT
};


gulp.task('build:sass', function() {
  return gulp.src(path.sass.from)
    .pipe(sourcemaps.init())
    .pipe(sass().on('error', function(err) {
      var displayErr = gutil.colors.red(err);
      gutil.log(displayErr);
      gutil.beep();
      this.emit('end');
    }))
    .pipe(autoprefixer({
      browsers: ['last 3 versions'],
      cascade: false
    }))
    .pipe(sass({
      outputStyle: 'compressed'
    }).on('error', sass.logError))
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest('./public/css'));

});

gulp.task('build:jade', function() {
  return gulp.src(path.jade.from)
    .pipe(jade({
      pretty: true
    }).on('error', function(err) {
      var displayErr = gutil.colors.red(err);
      gutil.log(displayErr);
      gutil.beep();
      this.emit('end');
    }))
    .pipe(gulp.dest('./public/html'));
});


function compileJade(file) {

  return gulp.src(file)
    .pipe(changed('./public/html', {
      extension: '.html'
    }))
    .pipe(gulpif(true, cached('jade')))
    .pipe(jadeInheritance({
      basedir: 'source/jade'
    }))
    .pipe(filter(function(file) {
      return !/\/_/.test(file.path) && !/^_/.test(file.relative);
    }))
    .pipe(jade({
      pretty: true
    }).on('error', function(err) {
      var displayErr = gutil.colors.red(err);
      gutil.log(displayErr);
      gutil.beep();
      this.emit('end');
    }))
    .pipe(gulp.dest('./public/html'))
    .pipe(notify({
      message: "File <%= file.relative %> builded!"
    }));

}

gulp.task('connect', function() {
  connect.server({
    port: config.port,
    root: './public',
    middleware: function() {
      return [compression()];
    }
  });
});

gulp.task('open', function() {
  gulp.src('')
    .pipe(open({
      uri: 'http://localhost:' + config.port + (my.MY_BROWSER_HTML || "/html/")
    }));
});

gulp.task('watch', function() {
  //jade
  gulp.watch(path.jade.watch, function(event) {
    return compileJade(event.path);
  });

  gulp.watch(path.sass.watch, ['build:sass']);
});


gulp.task('default', ['build:sass', 'watch', 'connect', 'open']);
